==> bakery2.0_2.0.0.orig.tar.gz: bakery-2.0.0/examples/Configuration/Dialog_Preferences/examplewindow.cc <==
//$Id: examplewindow.cc,v 1.5 2003/02/15 16:06:27 murrayc Exp $ -*- c++ -*-

/* gtkmm example Copyright (C) 2002 gtkmm development team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <libintl.h>

#include "examplewindow.h"
#include "exampledialog.h"
#include <iostream>

ExampleWindow::ExampleWindow()
: m_Button_Preferences_Delayed(gettext("Preferences (apply on close)")),
  m_Button_Preferences_Instant(gettext("Preferences (instant apply)"))
{  
  // Sets the border width of the window.
  set_border_width(10);

  add(m_VBox);
  m_VBox.pack_start(m_Button_Preferences_Delayed);
  m_VBox.pack_start(m_Button_Preferences_Instant);

  //Connect button's signal handler:
  m_Button_Preferences_Delayed.signal_clicked().connect( SigC::slot(*this, &ExampleWindow::on_delayed_button_clicked) );
  m_Button_Preferences_Instant.signal_clicked().connect( SigC::slot(*this, &ExampleWindow::on_instant_button_clicked) );

  show_all_children();
}

ExampleWindow::~ExampleWindow()
{
}

void ExampleWindow::on_delayed_button_clicked()
{
  //Show the preferences dialog:
  ExampleDialog preferences(*this, false);
  preferences.run();
}

void ExampleWindow::on_instant_button_clicked()
{
  //Show the preferences dialog:
  ExampleDialog preferences(*this,true);
  preferences.run();
}

==> bakery2.3_2.3.11.orig.tar.gz: bakery-2.3.11/examples/Configuration/Dialog_Preferences/examplewindow.cc <==
//$Id: examplewindow.cc,v 1.6 2004/02/16 14:17:53 murrayc Exp $ -*- c++ -*-

/* gtkmm example Copyright (C) 2002 gtkmm development team
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <libintl.h>

#include "examplewindow.h"
#include "exampledialog.h"
#include <iostream>

ExampleWindow::ExampleWindow()
: m_Button_Preferences_Delayed(gettext("Preferences (apply on close)")),
  m_Button_Preferences_Instant(gettext("Preferences (instant apply)"))
{  
  // Sets the border width of the window.
  set_border_width(10);

  add(m_VBox);
  m_VBox.pack_start(m_Button_Preferences_Delayed);
  m_VBox.pack_start(m_Button_Preferences_Instant);

  //Connect button's signal handler:
  m_Button_Preferences_Delayed.signal_clicked().connect( sigc::mem_fun(*this, &ExampleWindow::on_delayed_button_clicked) );
  m_Button_Preferences_Instant.signal_clicked().connect( sigc::mem_fun(*this, &ExampleWindow::on_instant_button_clicked) );

  show_all_children();
}

ExampleWindow::~ExampleWindow()
{
}

void ExampleWindow::on_delayed_button_clicked()
{
  //Show the preferences dialog:
  ExampleDialog preferences(*this, false);
  preferences.run();
}

void ExampleWindow::on_instant_button_clicked()
{
  //Show the preferences dialog:
  ExampleDialog preferences(*this,true);
  preferences.run();
}
